==> hoteldruid_2.1.4.orig.tar.gz: hoteldruid/includes/lang/es/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
case "documento":  				$messaggio = "documento"; break;
case "Modifica il documento":  			$messaggio = "Modificar el documento"; break;
case "Salva le modifiche":  			$messaggio = "Salvar los cambios"; break;
case "Visualizza il documento":  		$messaggio = "Mirar el documento"; break;
case "Documento salvato":  			$messaggio = "Documento salvado"; break;
case "Variabili":  				$messaggio = "Variables"; break;
case "Limiti":  				$messaggio = "Límites"; break;
case "Aggiungi":  				$messaggio = "Añadir"; break;
case "Cambia":  				$messaggio = "Cambiar"; break;
case "Formato del documento":  			$messaggio = "Formato del documento"; break;
case "EMAIL":  					$messaggio = "EMAIL"; break;
case "Oggetto":  				$messaggio = "Asunto"; break;
case "Formato del documento cambiato":  	$messaggio = "Formato del documento cambiado"; break;
case "Oggetto cambiato":  			$messaggio = "Asunto cambiado"; break;
case "Allegato":  				$messaggio = "Adjuntado"; break;
case "Elimina":  				$messaggio = "Eliminar"; break;
case "Mandare una copia bcc":  			$messaggio = "Enviar una copia bcc"; break;
case "al mittente":  				$messaggio = "al remitente"; break;
case "all'indirizzo":  				$messaggio = "a la dirección"; break;
case "Allegato salvato":  			$messaggio = "Adjuntado salvado"; break;
case "Allegato eliminato":  			$messaggio = "Adjuntado eliminado"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Copias bcc a enviar cambiadas"; break;
case "ripetizione prenotazioni":  		$messaggio = "repetición reservas"; break;
case "ripetizione ospiti":  			$messaggio = "repetición huéspdes"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "repetición costes añadidos"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "SUBSTITUIR CON PARTE A REPETIR PARA CADA RESERVA"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "SUBSTITUIR CON LISTA HUéSPEDES EN RESERVA"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "SUBSTITUIR CON LISTA COSTES EN RESERVA"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Salvar los documentos con número progresivo en el directorio"; break;
case "I documenti non verranno salvati":	$messaggio = "Los documentos no serán salvados"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Los documentos serán salvados en el directorio"; break;
case "ripetizione array":  			$messaggio = "repetición array"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "SUBSTITUIR CON PARTE A REPETIR PARA CADA VALOR DEL ARRAY"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error en las repeticiones y condiciones anidadas"; break;
case "parte sotto condizione":  		$messaggio = "parte bajo condición"; break;
case "nome_variabile":  			$messaggio = "nombre_variable"; break;
case "valore":  				$messaggio = "valor"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "SUBSTITUIR CON PARTE A ENSEÑAR SOLO SI SE VERIFICA LA CONDICóN ANTERIOR"; break;
case "OPPURE":  				$messaggio = "O"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Variables personalizadas y condiciones del documento"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Compartir el número progresivo con"; break;
case "il documento":  				$messaggio = "el documento"; break;
case "Usa come nome del file":  		$messaggio = "Utilizar como nombre del archivo"; break;
case "il nome del documento":  			$messaggio = "el nombre del documento"; break;
case "un altro nome":  				$messaggio = "otro nombre"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "no compartirá el número progresivo con ningún documento"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "compartirá el número progresivo con el documento"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Los archivos serán salvados con el nombre del documento"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Los archivos serán salvados con el nombre"; break;
case "Salva automaticamente il documento":  	$messaggio = "Salvar automaticamente el documento"; break;
case "mai":  					$messaggio = "nunca"; break;
case "alla registrazione dell'entrata":  	$messaggio = "a la registración de la entrada"; break;
case "alla registrazione dell'uscita":  	$messaggio = "a la registración de la salida"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "El documento será salvado automaticamente"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "El documento no será salvado automaticamente"; break;
case "multi-lingua":  				$messaggio = "multi-idioma"; break;
case "in":  					$messaggio = "en"; break;
case "Avviso":  				$messaggio = "Aviso"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "en los documentos en formato multi-idioma no es posible repetir una sola parte con los tags [r] y [/r], el documento es repetido por entero con cada reserva"; break;
case "predefinito":  				$messaggio = "predefinido"; break;
case "fai predefinito":  			$messaggio = "hacer predefinido"; break;
case "Comprimi i file":  			$messaggio = "Comprimir los archivos"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "El documento no será salvado comprimido sobre disco"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "El documento será salvado comprimido sobre disco"; break;
case "Formato dell'email":  			$messaggio = "Formato del correo"; break;
case "testo semplice":  			$messaggio = "texto simple"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Formato del correo electrónico cambiado"; break;
case "ripetizione pagamenti":  			$messaggio = "repetición pagos"; break;
case "ripetizione unità":  			$messaggio = "repetición unidades"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "SUBSTITUIR CON LISTA PAGOS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Encabezado html personalizado"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modificar el encabezado html"; break;
case "Modifica la chiusura html":  		$messaggio = "Modificar el cierre html"; break;
case "Intestazione html cambiata":  		$messaggio = "Encabezado html cambiado"; break;
case "Chiusura html cambiata":  		$messaggio = "Cierre html cambiado"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Incrementar el número progresivo cada vez que aparece"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Cada documento tendrá un único número progresivo"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "El número progresivo será incrementado daca vez que aparezca en el documento"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extensión para ver y descargar el documento"; break;
case "predefinita":  				$messaggio = "predefinida"; break;
case "personalizzata":  			$messaggio = "personalizada"; break;
case "Estensione cambiata":  			$messaggio = "Extensión cambiada"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid_2.2.0.orig.tar.gz: hoteldruid/includes/lang/es/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "documento":  				$messaggio = "documento"; break;
case "Modifica il documento":  			$messaggio = "Modificar el documento"; break;
case "Salva le modifiche":  			$messaggio = "Salvar los cambios"; break;
case "Visualizza il documento":  		$messaggio = "Mirar el documento"; break;
case "Documento salvato":  			$messaggio = "Documento salvado"; break;
case "Variabili":  				$messaggio = "Variables"; break;
case "Limiti":  				$messaggio = "Límites"; break;
case "Aggiungi":  				$messaggio = "Añadir"; break;
case "Cambia":  				$messaggio = "Cambiar"; break;
case "Formato del documento":  			$messaggio = "Formato del documento"; break;
case "EMAIL":  					$messaggio = "EMAIL"; break;
case "Oggetto":  				$messaggio = "Asunto"; break;
case "Formato del documento cambiato":  	$messaggio = "Formato del documento cambiado"; break;
case "Oggetto cambiato":  			$messaggio = "Asunto cambiado"; break;
case "Allegato":  				$messaggio = "Adjuntado"; break;
case "Elimina":  				$messaggio = "Eliminar"; break;
case "Mandare una copia bcc":  			$messaggio = "Enviar una copia bcc"; break;
case "al mittente":  				$messaggio = "al remitente"; break;
case "all'indirizzo":  				$messaggio = "a la dirección"; break;
case "Allegato salvato":  			$messaggio = "Adjuntado salvado"; break;
case "Allegato eliminato":  			$messaggio = "Adjuntado eliminado"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Copias bcc a enviar cambiadas"; break;
case "ripetizione prenotazioni":  		$messaggio = "repetición reservas"; break;
case "ripetizione ospiti":  			$messaggio = "repetición huéspdes"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "repetición costes añadidos"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "SUBSTITUIR CON PARTE A REPETIR PARA CADA RESERVA"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "SUBSTITUIR CON LISTA HUéSPEDES EN RESERVA"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "SUBSTITUIR CON LISTA COSTES EN RESERVA"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Salvar los documentos con número progresivo en el directorio"; break;
case "I documenti non verranno salvati":	$messaggio = "Los documentos no serán salvados"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Los documentos serán salvados en el directorio"; break;
case "ripetizione array":  			$messaggio = "repetición array"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "SUBSTITUIR CON PARTE A REPETIR PARA CADA VALOR DEL ARRAY"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error en las repeticiones y condiciones anidadas"; break;
case "parte sotto condizione":  		$messaggio = "parte bajo condición"; break;
case "nome_variabile":  			$messaggio = "nombre_variable"; break;
case "valore":  				$messaggio = "valor"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "SUBSTITUIR CON PARTE A ENSEÑAR SOLO SI SE VERIFICA LA CONDICóN ANTERIOR"; break;
case "OPPURE":  				$messaggio = "O"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Variables personalizadas y condiciones del documento"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Compartir el número progresivo con"; break;
case "il documento":  				$messaggio = "el documento"; break;
case "Usa come nome del file":  		$messaggio = "Utilizar como nombre del archivo"; break;
case "il nome del documento":  			$messaggio = "el nombre del documento"; break;
case "un altro nome":  				$messaggio = "otro nombre"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "no compartirá el número progresivo con ningún documento"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "compartirá el número progresivo con el documento"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Los archivos serán salvados con el nombre del documento"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Los archivos serán salvados con el nombre"; break;
case "Salva automaticamente il documento":  	$messaggio = "Salvar automaticamente el documento"; break;
case "mai":  					$messaggio = "nunca"; break;
case "alla registrazione dell'entrata":  	$messaggio = "a la registración de la entrada"; break;
case "alla registrazione dell'uscita":  	$messaggio = "a la registración de la salida"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "El documento será salvado automaticamente"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "El documento no será salvado automaticamente"; break;
case "multi-lingua":  				$messaggio = "multi-idioma"; break;
case "in":  					$messaggio = "en"; break;
case "Avviso":  				$messaggio = "Aviso"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "en los documentos en formato multi-idioma no es posible repetir una sola parte con los tags [r] y [/r], el documento es repetido por entero con cada reserva"; break;
case "predefinito":  				$messaggio = "predefinido"; break;
case "fai predefinito":  			$messaggio = "hacer predefinido"; break;
case "Comprimi i file":  			$messaggio = "Comprimir los archivos"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "El documento no será salvado comprimido sobre disco"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "El documento será salvado comprimido sobre disco"; break;
case "Formato dell'email":  			$messaggio = "Formato del correo"; break;
case "testo semplice":  			$messaggio = "texto simple"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Formato del correo electrónico cambiado"; break;
case "ripetizione pagamenti":  			$messaggio = "repetición pagos"; break;
case "ripetizione unità":  			$messaggio = "repetición unidades"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "SUBSTITUIR CON LISTA PAGOS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Encabezado html personalizado"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modificar el encabezado html"; break;
case "Modifica la chiusura html":  		$messaggio = "Modificar el cierre html"; break;
case "Intestazione html cambiata":  		$messaggio = "Encabezado html cambiado"; break;
case "Chiusura html cambiata":  		$messaggio = "Cierre html cambiado"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Incrementar el número progresivo cada vez que aparece"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Cada documento tendrá un único número progresivo"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "El número progresivo será incrementado daca vez que aparezca en el documento"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extensión para ver y descargar el documento"; break;
case "predefinita":  				$messaggio = "predefinida"; break;
case "personalizzata":  			$messaggio = "personalizada"; break;
case "Estensione cambiata":  			$messaggio = "Extensión cambiada"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
